antares.apps.accounting.templatetags package
============================================

Submodules
----------

antares.apps.accounting.templatetags.accounting\_tags module
------------------------------------------------------------

.. automodule:: antares.apps.accounting.templatetags.accounting_tags
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.accounting.templatetags
   :members:
   :undoc-members:
   :show-inheritance:
